[−][src]Enum unicode_types::tibetan::Tibetan
An enum to represent all characters in the Tibetan block.
Variants
SyllableOm\u{f00}: 'ༀ'
MarkGterYigMgoTruncatedA\u{f01}: '༁'
MarkGterYigMgoDashUmRnamBcadMa\u{f02}: '༂'
MarkGterYigMgoDashUmGterTshegMa\u{f03}: '༃'
MarkInitialYigMgoMdunMa\u{f04}: '༄'
MarkClosingYigMgoSgabMa\u{f05}: '༅'
MarkCaretYigMgoPhurShadMa\u{f06}: '༆'
MarkYigMgoTshegShadMa\u{f07}: '༇'
MarkSbrulShad\u{f08}: '༈'
MarkBskurYigMgo\u{f09}: '༉'
MarkBkaDashShogYigMgo\u{f0a}: '༊'
MarkIntersyllabicTsheg\u{f0b}: '་'
MarkDelimiterTshegBstar\u{f0c}: '༌'
MarkShad\u{f0d}: '།'
MarkNyisShad\u{f0e}: '༎'
MarkTshegShad\u{f0f}: '༏'
MarkNyisTshegShad\u{f10}: '༐'
MarkRinChenSpungsShad\u{f11}: '༑'
MarkRgyaGramShad\u{f12}: '༒'
\u{f13}: '༓'
MarkGterTsheg\u{f14}: '༔'
\u{f15}: '༕'
\u{f16}: '༖'
\u{f17}: '༗'
AstrologicalSignDashKhyudPa\u{f18}: '༘'
AstrologicalSignSdongTshugs\u{f19}: '༙'
SignRdelDkarGcig\u{f1a}: '༚'
SignRdelDkarGnyis\u{f1b}: '༛'
SignRdelDkarGsum\u{f1c}: '༜'
SignRdelNagGcig\u{f1d}: '༝'
SignRdelNagGnyis\u{f1e}: '༞'
SignRdelDkarRdelNag\u{f1f}: '༟'
DigitZero\u{f20}: '༠'
DigitOne\u{f21}: '༡'
DigitTwo\u{f22}: '༢'
DigitThree\u{f23}: '༣'
DigitFour\u{f24}: '༤'
DigitFive\u{f25}: '༥'
DigitSix\u{f26}: '༦'
DigitSeven\u{f27}: '༧'
DigitEight\u{f28}: '༨'
DigitNine\u{f29}: '༩'
DigitHalfOne\u{f2a}: '༪'
DigitHalfTwo\u{f2b}: '༫'
DigitHalfThree\u{f2c}: '༬'
DigitHalfFour\u{f2d}: '༭'
DigitHalfFive\u{f2e}: '༮'
DigitHalfSix\u{f2f}: '༯'
DigitHalfSeven\u{f30}: '༰'
DigitHalfEight\u{f31}: '༱'
DigitHalfNine\u{f32}: '༲'
DigitHalfZero\u{f33}: '༳'
\u{f34}: '༴'
MarkNgasBzungNyiZla\u{f35}: '༵'
\u{f36}: '༶'
\u{f37}: '༷'
MarkCheMgo\u{f38}: '༸'
MarkTsaDashPhru\u{f39}: '༹'
\u{f3a}: '༺'
\u{f3b}: '༻'
MarkAngKhangGyon\u{f3c}: '༼'
MarkAngKhangGyas\u{f3d}: '༽'
SignYarTshes\u{f3e}: '༾'
SignMarTshes\u{f3f}: '༿'
LetterKa\u{f40}: 'ཀ'
LetterKha\u{f41}: 'ཁ'
LetterGa\u{f42}: 'ག'
LetterGha\u{f43}: 'གྷ'
LetterNga\u{f44}: 'ང'
LetterCa\u{f45}: 'ཅ'
LetterCha\u{f46}: 'ཆ'
LetterJa\u{f47}: 'ཇ'
LetterNya\u{f49}: 'ཉ'
LetterTta\u{f4a}: 'ཊ'
LetterTtha\u{f4b}: 'ཋ'
LetterDda\u{f4c}: 'ཌ'
LetterDdha\u{f4d}: 'ཌྷ'
LetterNna\u{f4e}: 'ཎ'
LetterTa\u{f4f}: 'ཏ'
LetterTha\u{f50}: 'ཐ'
LetterDa\u{f51}: 'ད'
LetterDha\u{f52}: 'དྷ'
LetterNa\u{f53}: 'ན'
LetterPa\u{f54}: 'པ'
LetterPha\u{f55}: 'ཕ'
LetterBa\u{f56}: 'བ'
LetterBha\u{f57}: 'བྷ'
LetterMa\u{f58}: 'མ'
LetterTsa\u{f59}: 'ཙ'
LetterTsha\u{f5a}: 'ཚ'
LetterDza\u{f5b}: 'ཛ'
LetterDzha\u{f5c}: 'ཛྷ'
LetterWa\u{f5d}: 'ཝ'
LetterZha\u{f5e}: 'ཞ'
LetterZa\u{f5f}: 'ཟ'
LetterDashA\u{f60}: 'འ'
LetterYa\u{f61}: 'ཡ'
LetterRa\u{f62}: 'ར'
LetterLa\u{f63}: 'ལ'
LetterSha\u{f64}: 'ཤ'
LetterSsa\u{f65}: 'ཥ'
LetterSa\u{f66}: 'ས'
LetterHa\u{f67}: 'ཧ'
LetterA\u{f68}: 'ཨ'
LetterKssa\u{f69}: 'ཀྵ'
LetterFixedDashFormRa\u{f6a}: 'ཪ'
LetterKka\u{f6b}: 'ཫ'
LetterRra\u{f6c}: 'ཬ'
VowelSignAa\u{f71}: 'ཱ'
VowelSignI\u{f72}: 'ི'
VowelSignIi\u{f73}: 'ཱི'
VowelSignU\u{f74}: 'ུ'
VowelSignUu\u{f75}: 'ཱུ'
VowelSignVocalicR\u{f76}: 'ྲྀ'
VowelSignVocalicRr\u{f77}: 'ཷ'
VowelSignVocalicL\u{f78}: 'ླྀ'
VowelSignVocalicLl\u{f79}: 'ཹ'
VowelSignE\u{f7a}: 'ེ'
VowelSignEe\u{f7b}: 'ཻ'
VowelSignO\u{f7c}: 'ོ'
VowelSignOo\u{f7d}: 'ཽ'
SignRjesSuNgaRo\u{f7e}: 'ཾ'
SignRnamBcad\u{f7f}: 'ཿ'
VowelSignReversedI\u{f80}: 'ྀ'
VowelSignReversedIi\u{f81}: 'ཱྀ'
SignNyiZlaNaaDa\u{f82}: 'ྂ'
SignSnaLdan\u{f83}: 'ྃ'
MarkHalanta\u{f84}: '྄'
MarkPaluta\u{f85}: '྅'
\u{f86}: '྆'
\u{f87}: '྇'
SignLceTsaCan\u{f88}: 'ྈ'
SignMchuCan\u{f89}: 'ྉ'
SignGruCanRgyings\u{f8a}: 'ྊ'
SignGruMedRgyings\u{f8b}: 'ྋ'
SignInvertedMchuCan\u{f8c}: 'ྌ'
SubjoinedSignLceTsaCan\u{f8d}: 'ྍ'
SubjoinedSignMchuCan\u{f8e}: 'ྎ'
SubjoinedSignInvertedMchuCan\u{f8f}: 'ྏ'
SubjoinedLetterKa\u{f90}: 'ྐ'
SubjoinedLetterKha\u{f91}: 'ྑ'
SubjoinedLetterGa\u{f92}: 'ྒ'
SubjoinedLetterGha\u{f93}: 'ྒྷ'
SubjoinedLetterNga\u{f94}: 'ྔ'
SubjoinedLetterCa\u{f95}: 'ྕ'
SubjoinedLetterCha\u{f96}: 'ྖ'
SubjoinedLetterJa\u{f97}: 'ྗ'
SubjoinedLetterNya\u{f99}: 'ྙ'
SubjoinedLetterTta\u{f9a}: 'ྚ'
SubjoinedLetterTtha\u{f9b}: 'ྛ'
SubjoinedLetterDda\u{f9c}: 'ྜ'
SubjoinedLetterDdha\u{f9d}: 'ྜྷ'
SubjoinedLetterNna\u{f9e}: 'ྞ'
SubjoinedLetterTa\u{f9f}: 'ྟ'
SubjoinedLetterTha\u{fa0}: 'ྠ'
SubjoinedLetterDa\u{fa1}: 'ྡ'
SubjoinedLetterDha\u{fa2}: 'ྡྷ'
SubjoinedLetterNa\u{fa3}: 'ྣ'
SubjoinedLetterPa\u{fa4}: 'ྤ'
SubjoinedLetterPha\u{fa5}: 'ྥ'
SubjoinedLetterBa\u{fa6}: 'ྦ'
SubjoinedLetterBha\u{fa7}: 'ྦྷ'
SubjoinedLetterMa\u{fa8}: 'ྨ'
SubjoinedLetterTsa\u{fa9}: 'ྩ'
SubjoinedLetterTsha\u{faa}: 'ྪ'
SubjoinedLetterDza\u{fab}: 'ྫ'
SubjoinedLetterDzha\u{fac}: 'ྫྷ'
SubjoinedLetterWa\u{fad}: 'ྭ'
SubjoinedLetterZha\u{fae}: 'ྮ'
SubjoinedLetterZa\u{faf}: 'ྯ'
SubjoinedLetterDashA\u{fb0}: 'ྰ'
SubjoinedLetterYa\u{fb1}: 'ྱ'
SubjoinedLetterRa\u{fb2}: 'ྲ'
SubjoinedLetterLa\u{fb3}: 'ླ'
SubjoinedLetterSha\u{fb4}: 'ྴ'
SubjoinedLetterSsa\u{fb5}: 'ྵ'
SubjoinedLetterSa\u{fb6}: 'ྶ'
SubjoinedLetterHa\u{fb7}: 'ྷ'
SubjoinedLetterA\u{fb8}: 'ྸ'
SubjoinedLetterKssa\u{fb9}: 'ྐྵ'
SubjoinedLetterFixedDashFormWa\u{fba}: 'ྺ'
SubjoinedLetterFixedDashFormYa\u{fbb}: 'ྻ'
SubjoinedLetterFixedDashFormRa\u{fbc}: 'ྼ'
KuRuKha\u{fbe}: '྾'
KuRuKhaBzhiMigCan\u{fbf}: '྿'
CantillationSignHeavyBeat\u{fc0}: '࿀'
CantillationSignLightBeat\u{fc1}: '࿁'
CantillationSignCangTeDashU\u{fc2}: '࿂'
CantillationSignSbubDashChal\u{fc3}: '࿃'
SymbolDrilBu\u{fc4}: '࿄'
SymbolRdoRje\u{fc5}: '࿅'
SymbolPadmaGdan\u{fc6}: '࿆'
SymbolRdoRjeRgyaGram\u{fc7}: '࿇'
SymbolPhurPa\u{fc8}: '࿈'
SymbolNorBu\u{fc9}: '࿉'
SymbolNorBuNyisDashKhyil\u{fca}: '࿊'
SymbolNorBuGsumDashKhyil\u{fcb}: '࿋'
SymbolNorBuBzhiDashKhyil\u{fcc}: '࿌'
SignRdelNagRdelDkar\u{fce}: '࿎'
SignRdelNagGsum\u{fcf}: '࿏'
MarkBskaDashShogGiMgoRgyan\u{fd0}: '࿐'
MarkMnyamYigGiMgoRgyan\u{fd1}: '࿑'
MarkNyisTsheg\u{fd2}: '࿒'
MarkInitialBrdaRnyingYigMgoMdunMa\u{fd3}: '࿓'
MarkClosingBrdaRnyingYigMgoSgabMa\u{fd4}: '࿔'
RightDashFacingSvastiSign\u{fd5}: '࿕'
LeftDashFacingSvastiSign\u{fd6}: '࿖'
RightDashFacingSvastiSignWithDots\u{fd7}: '࿗'
LeftDashFacingSvastiSignWithDots\u{fd8}: '࿘'
\u{fd9}: '࿙'
\u{fda}: '࿚'
Methods
impl Tibetan[src]
pub fn new() -> Self[src]
The character with the lowest index in this unicode block
pub fn name(&self) -> String[src]
The character's name, in sentence case